# IT Component Modeling Guidelines
### On this page
  * [Definition](https://help.sap.com/docs/leanix/ea/it-component-modeling-guidelines#definition)
  * [Description](https://help.sap.com/docs/leanix/ea/it-component-modeling-guidelines#description)
  * [IT Component Fact Sheet Subtypes](https://help.sap.com/docs/leanix/ea/it-component-modeling-guidelines#it-component-fact-sheet-subtypes)
  * [Guidelines and Best Practices](https://help.sap.com/docs/leanix/ea/it-component-modeling-guidelines#guidelines-and-best-practices)
  * [Antipatterns](https://help.sap.com/docs/leanix/ea/it-component-modeling-guidelines#antipatterns)
  * [Applicable Use Cases](https://help.sap.com/docs/leanix/ea/it-component-modeling-guidelines#applicable-use-cases)
  * [Insights from IT Component Fact Sheet](https://help.sap.com/docs/leanix/ea/it-component-modeling-guidelines#insights-from-it-component-fact-sheet)
  * [Scenarios for the AI Model Subtype](https://help.sap.com/docs/leanix/ea/it-component-modeling-guidelines#scenarios-for-the-ai-model-subtype)


View all
Learn how to model IT components. This includes best practices and applicable use cases, and common antipatterns.
**Note**
These modeling guidelines are for the meta model v4. For meta model v3 guidelines, see [Modeling: IT Components / Hosting](https://help.sap.com/docs/leanix/ea/it-components-hosting-modeling-v3?locale=en-US&state=PRODUCTION&version=CLOUD "Modeling Application hosting is a common challenge for all enterprise architects. While it is possible to spend years discussing the perfect model that captures every single edge case, this section provides three step-by-step guides that we recommend and that can be applied based on your needs. There is an entry-level approach, a pragmatic one as well as the full-fledged option.").
